% Lap = divand_laplacian(mask,pmn,nu);
%
% Form a Laplacian using finite differences
% assumes that gradient is zero at "coastline"
%
% Input:
%   mask: binary mask delimiting the domain. 1 is inside and 0 outside.
%         For oceanographic application, this is the land-sea mask.
%   pmn: scale factor of the grid. 
%   nu: diffusion coefficient of the Laplacian
%
% Output:
%   Lap: sparce matrix represeting a Laplaciant 
%
% 
function Lap = divand_laplacian(mask,pmn,nu)

pmn = cat_cell_array(pmn);

% number of dimensions
n = size(pmn,ndims(pmn));

sz = size(mask);

if nargin == 2
  nu = ones(sz);
end

if isequal(sz,size(nu))
  % assume diffusion is the same along all dimensions
  nu = repmat(nu,[ones(1,n) n]);
end

% nu: 1st index represents the dimensions 
nu = permute(nu,[n+1 1:n]);

% extraction operator of sea points
H = sparse_pack(mask==1);


sz = size(mask);

DD = sparse(0);

Pmn = reshape(pmn,[prod(sz) n]);    
for i=1:n
  % operator for staggering in dimension i
  S = sparse_stagger(sz,i);

  % d = 1 for interfaces surounded by water, zero otherwise
  d = S * mask(:) == 1;
  
  % metric
  for j = 1:n
    tmp = S * Pmn(:,j);
    
    if j==i
      d = d .* tmp;
    else
      d = d ./ tmp;
    end  
  end
  
  % tmp: "diffusion coefficient"  along dimension i  
  tmp = nu(i,:);
  
  %whos tmp d S nu
  %keyboard
  d = d .* (S * tmp(:));

  % extx: extension operator
  szt = sz;
  szt(i) = szt(i)+1;
  extx = sparse_trim(szt,i)';
  
  % Flux operators D
  % zero at "coastline"
  D = extx * sparse_diag(d) * sparse_diff(sz,i);
  
  % add laplacian along dimension i  
  DD = DD + sparse_diff(szt,i) * D;
  
end

ivol = prod(pmn,n+1);

% Laplacian on regualar grid DD
DD = sparse_diag(ivol) * DD;

% Laplacian on grid with on sea points Lap
Lap = H * DD * H';


